#!/bin/sh

#    Copyright  2007 Sun Microsystems, Inc. All rights reserved
#
#    Use is subject to license terms.

# --------------------------------------------------------------------------------
#      Simple shell script for running Java RTS "Getting Started" scenarios
# --------------------------------------------------------------------------------

#  This is a primitive bourne shell script that automatically runs the various
#  scenarios described in the Java RTS Getting Started html document.
#  The architecture of this script is voluntarily minimal to encourage
#  modifications and various trials of the runs.
# 
#  Usage:
#  -----
#    run-scenarios <vanilla-java-command> <javaRTS-java-command> <verbose-flag> <getting-started-jar> <optional-VM-Args>
# 
#     <vanilla-java-command>:
#       path and binary java command for the vanilla Java VM to use
#     <javaRTS-java-command>:
#       path and binary java command for the Java RTS VM to use
#     <verbose-flag>:
#       "verbose" will produce detailed output from the programs
#     <getting-started-jar>:
#       path and filename of the GettingStarted.jar
#     <optional-VM-Args>:
#       arguments that you may want to pass to vanilla Java VM and Java RTS VM
# 
#  Modifying the Script File
#  -------------------------
#    For each scenario within this script, you can change the input parameters
#    for the example programs by changing the values of the script variables that
#    represent the bench thread and stress thread parameters. See the
#    Getting Started document for a complete description.
#  
#    These script parameters are called
#       JLT_BENCH_ARGS, JLT_STRESS_ARGS, RT_BENCH_ARGS, RT_STRESS_ARGS.
#   
#       The  script  file  first  reads  the passed  arguments  and  sets
#       constants for the run (the machine name, minimal common arguments
#       for each java invocation, working directory name, and so forth).
#       
#       Each scenario is enclosed in a section as follows:
#       
#           * The scenario is given a file name (RUN_NAME variable).
#       
#           * The bench thread is provided arguments for the run, using
#             variables called either JLT_BENCH_THREAD or
#             RT_BENCH_THREAD, depending on whether the bench thread is a
#             JLT or an RTT.
#       
#           * If  needed, the  RTT stress  thread is  provided arguments,
#             using the variable RT_STRESS_THREAD.
#       
#           * The JLT  stress thread is  provided arguments for  the run,
#             using the variable JLT_STRESS_THREAD.
#       
#    Thus you  have just to  modify JLT_BENCH_THREAD, RT_BENCH_THREAD,
#    RT_STRESS_THREAD,  JLT_STRESS_THREAD variables  to change  any of
#    the scenario runs.
#
#  Example Programs Input
#  ----------------------
#     For the NonDeterministic and GCDeterministic programs,
#     the script parameters have format:
#   
#       xx_xxxxx_ARGS='<outer> <inner> <class> <size> <pause> <priority>'
#    
#        where
#            <outer> is an integer, the number of outer iterations
#            <inner> is an integer, the number of inner iterations
#            <class> is an integer, the number of class iterations
#            <size>  is an integer, the allocation array size
#            <pause> is an integer, the pause time in milliseconds
#            <priority> is the thread priority level, "max", "norm", or "min"
#       
#      An example for the NonDeterministic program:
#            JLT_BENCH_ARGS='1000 20 10 0 0 norm'
#    
#     For the Deterministic program, the script parameters have the same format:
#   
#        xx_xxxxx_ARGS='<outer> <inner> <class> <pause> <priority>'
#    
#      Notice that that the <size> parameter is not present for Deterministic.
#      An example for the Deterministic program:
#           RT_STRESS_ARGS='0 20 10 10 min'
#
#  Output:
#  ------
#    A trace of the different VM invocations, and for each scenario creation
#    of text files containing the output of the example program that was run.
#   
#  Description:
#  ----------- 
#    The script first creates a directory with the following name:
#     results-<host>-<exec-time> where:
#       <host>: hostname of the machine on which the script is run.
#       <exec-time>: the time (day+hour) when the directory was created.
#
#    It then changes the directory to the above directory and runs the various
#    scenarios with the passed parameters.
#    ---------------------------------------------------------------------------
#    The script then executes all the scenarios described in the Getting Started
#    document and stores the output of the programs in files, each of which has
#    a name in the following format:
#      
#      <host>-<vmname>-<pgmname>-<nb-run>-[ITC]-<bench-thread>-<params>-<<stress-thread>-<params>+>-[JIT]-[PS1|PS2]-<Small|Medium|Large>-<exec-time>
# 
#    where: 
#      <host>: hostname of the machine on which the script is run
#
#      <vmname>: Java VM name on which the scenarios was run
#         either "JavaVanilla" or "JavaRTS20"
#
#      <pgmname>: program name.
#         One of "NonDeterministic", "Deterministic", "GCDeterministic"
#
#      <nb-run>: the scenario number for program above, as stated in
#         Getting Started document
#
#      "ITC": optional. Indicates if the run was executed under ITC compilation
#         system or not
#
#      <bench-thread>: bench thread type. One of the following:
#          "BJLT" for java.lang.Thread bench thread
#          "BRT"  for javax.RealtimeThread bench thread
#
#      <params>: thread parameter with format "<prio><alloc><pause>["resBytes"]
#          where:
#           <prio>:  one of PrMin, PrNorm, PrMax
#           <alloc>: one of NoAlloc, NormAlloc, BigAlloc, MaxAlloc
#           <pause>: one of NoPause, SmallPause, NormPause, BigPause
#           ["ResBytes"]: optional (RTT threads only) .
#              flag for presence of reserved bytes area
#
#      <<stress-thread>-<params>+>: There are 2 stress threads at most
#        Specify which stress was run, as follows:
#          <stress-thread>: stress thread type. One of the following:
#            "SJLT" for java.lang.Thread stress thread
#            "SRT"  for javax.RealtimeThread stress thread
#          <params>: parameter string for the stress thread.
#             Same format as for the bench thread, see above.
#
#      "JIT": optional.
#        Indicates if the JIT compilation has been forced or not for this run
#
#      "PS1"|"PS2": optional.
#        Indicates if run was executed in a processor set with 1 or 2 processors
#
#      <Small|Medium|Large>: number of outer iterations, for a heap memory max of 64Mb.
#         The values mean:
#           Small: number of outer iterations less than 1000.
#           Medium: number of outer iterations between 1000 and 5000.
#           Large: number of outer iterations at least 5000.
#
#      <exec-time>: the time (day+hour) when the output file was created.
#
#  
#    ---------------------------------------------------------------------------
# 
#    Java RTS ITC compilation system produces in addition the following files in the
#    above directory:
#      "nhrt.precompile": precompilation of class files
#      "itc.preload": preload list of class files
#      "itc.preinit": preinit list of class files
# 
#    ---------------------------------------------------------------------------

  
# SCRIPT PARAMETERS
# -----------------
VANILLA_VM_BIN=$1
JAVARTS20_VM_BIN=$2
VERBOSE=$3
GETTING_STARTED_JAR=$4

# remaining parameters
shift 4
VM_ARGS=$*

# INTERNAL VARIABLES
# ------------------
# recurrent vm args
COMMON_ARGS='-XX:+PrintGC -classpath'

# host name
HOST_NAME=`uname -n`

# creates the result dir
EXEC_TIME=`date '+%m%d%y-%H''%M'`
WORKING_DIR=results-${HOST_NAME}-${EXEC_TIME}
mkdir ${WORKING_DIR}
cd ${WORKING_DIR}

# ===============================================================
# --- running NonDeterministic scenarios
# ===============================================================

echo "# ------------------ NonDeterministic Run1 --------------------\n"
RUN_NAME='VanillaVM-NonDeterministic-run1-BJLT-PrMaxNoAllocNoPause-Client-SJLT-PrMinNoAllocNoPause-PS1-Small'
psradm -i 0
psrset -c 0
JLT_BENCH_ARGS='5000 20 10 0 0 max'
JLT_STRESS_ARGS='5000 20 10 0 0 min'
command_line="/usr/sbin/psrset -e 1 ${VANILLA_VM_BIN} -client  ${VM_ARGS} ${COMMON_ARGS} ${GETTING_STARTED_JAR} NonDeterministic ${JLT_BENCH_ARGS} ${JLT_STRESS_ARGS} ${VERBOSE}"
EXEC_TIME=`date '+%m%d%y-%H''%M'`
file_name=${HOST_NAME}-${RUN_NAME}-$EXEC_TIME
touch ${file_name}
echo ${command_line} >> ${file_name}
echo ${command_line}
${command_line} >> ${file_name}
psrset -d 1
psradm -n 0
echo "# --- NonDeterministic run1 completed \n\n\n"

echo "# ------------------ NonDeterministic Run2 --------------------\n"
RUN_NAME='VanillaVM-NonDeterministic-run2-BJLT-PrNormNoAllocNoPause-Client-SJLT-PrNormNoAllocNoPause-PS1-Medium'
psradm -i 0
psrset -c 0
JLT_BENCH_ARGS='1000 800 10 0 0 norm'
JLT_STRESS_ARGS='1000 800 10 0 0 norm'
command_line="/usr/sbin/psrset -e 1 ${VANILLA_VM_BIN} -client  ${VM_ARGS} ${COMMON_ARGS} ${GETTING_STARTED_JAR} NonDeterministic ${JLT_BENCH_ARGS} ${JLT_STRESS_ARGS} ${VERBOSE}"
EXEC_TIME=`date '+%m%d%y-%H''%M'`
file_name=${HOST_NAME}-${RUN_NAME}-$EXEC_TIME
touch ${file_name}
echo ${command_line} >> ${file_name}
echo ${command_line}
${command_line} >> ${file_name}
psrset -d 1
psradm -n 0
echo "# --- NonDeterministic run2 completed \n\n\n"

echo "# ------------------ NonDeterministic Run3 --------------------\n"
RUN_NAME='VanillaVM-NonDeterministic-run3-BJLT-PrMaxNoAllocNoPause-Client-SJLT-PrMinNoAllocNoPause-PS1-Medium'
psradm -i 0
psrset -c 0
JLT_BENCH_ARGS='1000 800 10 0 0 max'
JLT_STRESS_ARGS='1000 800 10 0 0 min'
command_line="/usr/sbin/psrset -e 1 ${VANILLA_VM_BIN} -client  ${VM_ARGS} ${COMMON_ARGS} ${GETTING_STARTED_JAR} NonDeterministic ${JLT_BENCH_ARGS} ${JLT_STRESS_ARGS} ${VERBOSE}"
EXEC_TIME=`date '+%m%d%y-%H''%M'`
file_name=${HOST_NAME}-${RUN_NAME}-${EXEC_TIME}
touch ${file_name}
echo ${command_line} >> ${file_name}
echo ${command_line}
${command_line} >> ${file_name}
psrset -d 1
psradm -n 0
echo "# --- NonDeterministic run3 completed \n\n\n"

echo "# ------------------ NonDeterministic Run4 --------------------\n"
RUN_NAME='VanillaVM-NonDeterministic-run4-BJLT-PrMaxNoAllocNoPause-Client-NoSJLT-PS1-Medium'
psradm -i 0
psrset -c 0
JLT_BENCH_ARGS='1000 800 10 0 0 max'
JLT_STRESS_ARGS='0 0 10 0 10 min'
command_line="/usr/sbin/psrset -e 1 ${VANILLA_VM_BIN} -client  ${VM_ARGS} ${COMMON_ARGS} ${GETTING_STARTED_JAR} NonDeterministic ${JLT_BENCH_ARGS} ${JLT_STRESS_ARGS} ${VERBOSE}"
EXEC_TIME=`date '+%m%d%y-%H''%M'`
file_name=${HOST_NAME}-${RUN_NAME}-${EXEC_TIME}
touch ${file_name}
echo ${command_line} >> ${file_name}
echo ${command_line}
${command_line} >> ${file_name}
psrset -d 1
psradm -n 0
echo "# --- NonDeterministic run4 completed \n\n\n"

echo "# ------------------ NonDeterministic Run5 --------------------\n"
RUN_NAME='VanillaVM-NonDeterministic-run5-BJLT-PrNormNoAllocNoPause-Client-SJLT-PrNormBigAllocNoPause-PS1-Medium'
psradm -i 0
psrset -c 0
JLT_BENCH_ARGS='1000 800 10 0 0 norm'
JLT_STRESS_ARGS='1000 800 10 500 0 norm'
command_line="/usr/sbin/psrset -e 1 ${VANILLA_VM_BIN} -client  ${VM_ARGS} ${COMMON_ARGS} ${GETTING_STARTED_JAR} NonDeterministic ${JLT_BENCH_ARGS} ${JLT_STRESS_ARGS} ${VERBOSE}"
EXEC_TIME=`date '+%m%d%y-%H''%M'`
file_name=${HOST_NAME}-${RUN_NAME}-${EXEC_TIME}
touch ${file_name}
echo ${command_line} >> ${file_name}
echo ${command_line}
${command_line} >> ${file_name}
psrset -d 1
psradm -n 0
echo "# --- NonDeterministic run5 completed \n\n\n"

echo "# ------------------ NonDeterministic Run6 --------------------\n"
RUN_NAME='VanillaVM-NonDeterministic-run6-BJLT-PrMaxNoAllocNoPause-Client-SJLT-PrMinBigAllocNoPause-PS1-Medium'
psradm -i 0
psrset -c 0
JLT_BENCH_ARGS='1000 800 10 0 0 max'
JLT_STRESS_ARGS='1000 800 10 500 0 min'
command_line="/usr/sbin/psrset -e 1 ${VANILLA_VM_BIN} -client  ${VM_ARGS} ${COMMON_ARGS} ${GETTING_STARTED_JAR} NonDeterministic ${JLT_BENCH_ARGS} ${JLT_STRESS_ARGS} ${VERBOSE}"
EXEC_TIME=`date '+%m%d%y-%H''%M'`
file_name=${HOST_NAME}-${RUN_NAME}-${EXEC_TIME}
touch ${file_name}
echo ${command_line} >> ${file_name}
echo ${command_line}
${command_line} >> ${file_name}
psrset -d 1
psradm -n 0
echo "# --- NonDeterministic run6 completed \n\n\n"

echo "# ------------------ NonDeterministic  Run7 --------------------\n"
RUN_NAME='VanillaVM-NonDeterministic-run7-BJLT-PrMaxBigAllocNoPause-Client-NoSJLT-PS1-Medium'
psradm -i 0
psrset -c 0
JLT_BENCH_ARGS='5000 80 10 200 0 max'
JLT_STRESS_ARGS='0 20 10 500 10 min'
command_line="/usr/sbin/psrset -e 1 ${VANILLA_VM_BIN} -client  ${VM_ARGS} ${COMMON_ARGS} ${GETTING_STARTED_JAR} NonDeterministic ${JLT_BENCH_ARGS} ${JLT_STRESS_ARGS} ${VERBOSE}"
EXEC_TIME=`date '+%m%d%y-%H''%M'`
file_name=${HOST_NAME}-${RUN_NAME}-${EXEC_TIME}
touch ${file_name}
echo ${command_line} >> ${file_name}
echo ${command_line}
${command_line} >> ${file_name}
psrset -d 1
psradm -n 0
echo "# --- NonDeterministic run7 completed \n\n\n"

# ------------------------------------------------------------

# ================================================================
# --- running Deterministic scenarios
# ================================================================

echo "# ------------------ Deterministic Run1 --------------------\n"
RUN_NAME='JavaRTS20-Deterministic-run1-BRT-PrMaxNoAllocNoPause-NoSRT-SJLT-PrMinNoAllocNoPause-Jit-PS1-Medium'
psradm -i 0
psrset -c 0
JAVARTS20_ARGS='-XX:-ITCRT -XX:+JITRT'
RT_BENCH_ARGS='1000 40 10 1 max'
RT_STRESS_ARGS='0 20 10 10 min'
JLT_STRESS_ARGS='1000 40 10 10 min'
command_line="/usr/sbin/psrset -e 1 ${JAVARTS20_VM_BIN} ${VM_ARGS} ${JAVARTS20_ARGS} ${COMMON_ARGS} ${GETTING_STARTED_JAR} Deterministic ${RT_BENCH_ARGS} ${RT_STRESS_ARGS} ${JLT_STRESS_ARGS} ${VERBOSE}"
EXEC_TIME=`date '+%m%d%y-%H''%M'`
file_name=${HOST_NAME}-${RUN_NAME}-${EXEC_TIME}
touch ${file_name}
echo ${command_line} >> ${file_name}
echo ${command_line}
${command_line} >> ${file_name}
psrset -d 1
psradm -n 0
echo "# --- Deterministic run1 completed \n\n\n"

echo "# ------------------ Deterministic Run2 --------------------\n"
RUN_NAME='JavaRTS20-Deterministic-run2-BRT-PrMaxNoAllocNoPause-SRT-PrMinNoAllocNoPause-SJLT-PrMinNoAllocNoPause-Jit-PS1-Medium'
psradm -i 0
psrset -c 0
JAVARTS20_ARGS='-XX:-ITCRT -XX:+JITRT'
RT_BENCH_ARGS='1000 40 10 1 max'
RT_STRESS_ARGS='1000 40 10 1 min'
JLT_STRESS_ARGS='1000 40 10 10 min'
command_line="/usr/sbin/psrset -e 1 ${JAVARTS20_VM_BIN} ${VM_ARGS} ${JAVARTS20_ARGS} ${COMMON_ARGS} ${GETTING_STARTED_JAR} Deterministic ${RT_BENCH_ARGS} ${RT_STRESS_ARGS} ${JLT_STRESS_ARGS} ${VERBOSE}"
EXEC_TIME=`date '+%m%d%y-%H''%M'`
file_name=${HOST_NAME}-${RUN_NAME}-${EXEC_TIME}
touch ${file_name}
echo ${command_line} >> ${file_name}
echo ${command_line}
${command_line} >> ${file_name}
psrset -d 1
psradm -n 0
echo "# --- Deterministic run2 completed \n\n\n"


echo "# ------------------ Deterministic Run3 --------------------\n"
JAVARTS20_ARGS='-XX:+ITCRT'
RT_BENCH_ARGS='100 20 10 0 max'
RT_STRESS_ARGS='0 20 10 0 min'
JLT_STRESS_ARGS='10 20 10 10 min'
# --- building precompilation list for next runs
${JAVARTS20_VM_BIN} -XX:+RTSJBuildCompilationList ${JAVARTS20_ARGS} ${COMMON_ARGS} ${GETTING_STARTED_JAR} Deterministic ${RT_BENCH_ARGS} ${RT_STRESS_ARGS} ${JLT_STRESS_ARGS} silent >> garbage_file
# --- building preload list for next runs
${JAVARTS20_VM_BIN} -Drtsj.precompile=nhrt.precompile -XX:+RTSJBuildPreloadList ${JAVARTS20_ARGS} ${COMMON_ARGS} ${GETTING_STARTED_JAR} Deterministic ${RT_BENCH_ARGS} ${RT_STRESS_ARGS} ${JLT_STRESS_ARGS} silent >> garbage_file
# --- 

RUN_NAME='JavaRTS20-Deterministic-run3-BRT-PrMaxNoAllocNoPause-SRT-PrMinNoAllocNoPause-SJLT-PrMinNoAllocNoPause-Large'
psradm -i 0
psrset -c 0
RT_BENCH_ARGS='5000 40 10 1 max'
RT_STRESS_ARGS='5000 40 10 1 min'
JLT_STRESS_ARGS='1000 40 10 10 min'
command_line="/usr/sbin/psrset -e 1 ${JAVARTS20_VM_BIN} -Drtsj.precompile=nhrt.precompile -Drtsj.preload=itc.preload ${VM_ARGS} ${JAVARTS20_ARGS} ${COMMON_ARGS} ${GETTING_STARTED_JAR} Deterministic ${RT_BENCH_ARGS} ${RT_STRESS_ARGS} ${JLT_STRESS_ARGS} ${VERBOSE}"
EXEC_TIME=`date '+%m%d%y-%H''%M'`
file_name=${HOST_NAME}-${RUN_NAME}-${EXEC_TIME}
touch ${file_name}
echo ${command_line} >> ${file_name}
echo ${command_line}
${command_line} >> ${file_name}
psrset -d 1
psradm -n 0
echo "# --- Deterministic run3 completed \n\n\n"
# ------------------------------------------------------------


# ================================================================
# --- running GCDeterministic scenarios 
# ================================================================

# --- building precompilation list for next runs
JAVARTS20_ARGS='-Xms64m -Xmx64m -XX:+ITCRT -XX:+PrintCompilation -XX:+PrintGC'
RT_BENCH_ARGS='100 20 10 10 0 max'
RT_STRESS_ARGS='0 20 10 10 0 min'
JLT_STRESS_ARGS='10 20 10 10 0 min'
${JAVARTS20_VM_BIN} -XX:+RTSJBuildCompilationList ${JAVARTS20_ARGS} ${COMMON_ARGS} ${GETTING_STARTED_JAR} GCDeterministic ${RT_BENCH_ARGS} ${RT_STRESS_ARGS} ${JLT_STRESS_ARGS} silent >> garbage_file
# --- building preload list for next runs
${JAVARTS20_VM_BIN} -Drtsj.precompile=nhrt.precompile -XX:+RTSJBuildPreloadList -XX:+RTSJBuildClassInitializationList ${JAVARTS20_ARGS} ${COMMON_ARGS} ${GETTING_STARTED_JAR} GCDeterministic ${RT_BENCH_ARGS} ${RT_STRESS_ARGS} ${JLT_STRESS_ARGS} silent >> garbage_file
# --- Compilation list built"


echo "# ------------------ GCDeterministic Run1 --------------------\n"
RUN_NAME='JavaRTS20-GCDeterministic-run1-ITC-BRT-MaxPrNoAllocNoPause-SRT-PrMinNormAllocNoPause-NoSJLT-PS1-Medium'
echo "launching run ${RUN_NAME}"
psradm -i 0
psrset -c 0
JAVARTS20_ARGS='-Xms64m -Xmx64m -XX:+ITCRT -XX:+PrintGC'
RT_BENCH_ARGS='1000 10 10 0 0 max'
RT_STRESS_ARGS='1000 10 10 300 0 min'
JLT_STRESS_ARGS='0 10 10 10 0 min'
command_line="/usr/sbin/psrset -e 1 ${JAVARTS20_VM_BIN} -Drtsj.precompile=nhrt.precompile -Drtsj.preload=itc.preload -Drtsj.preinit=itc.preinit ${VM_ARGS} ${JAVARTS20_ARGS} ${COMMON_ARGS} ${GETTING_STARTED_JAR} GCDeterministic ${RT_BENCH_ARGS} ${RT_STRESS_ARGS} ${JLT_STRESS_ARGS} ${VERBOSE}"
EXEC_TIME=`date '+%m%d%y-%H''%M'`
file_name=${HOST_NAME}-${RUN_NAME}-${EXEC_TIME}
touch ${file_name}
echo ${command_line} >> ${file_name}
echo ${command_line}
${command_line} >> ${file_name}
psrset -d 1
psradm -n 0
echo "# --- GCDeterministic run1 completed \n\n\n"

echo "# ------------------ GCDeterministic Run2 --------------------\n"
RUN_NAME='JavaRTS20-GCDeterministic-run2-ITC-BRT-MaxPrMaxAllocNoPause-SRT-PrMinNormAllocNoPause-NoSJLT-PS1-Medium'
echo "launching run ${RUN_NAME}"
psradm -i 0
psrset -c 0
JAVARTS20_ARGS='-Xms64m -Xmx64m -XX:+ITCRT -XX:+PrintGC'
RT_BENCH_ARGS='1000 10 10 500 0 max'
RT_STRESS_ARGS='1000 10 10 300 0 min'
JLT_STRESS_ARGS='0 10 10 10 0 min'
command_line="/usr/sbin/psrset -e 1 ${JAVARTS20_VM_BIN} -Drtsj.precompile=nhrt.precompile -Drtsj.preload=itc.preload -Drtsj.preinit=itc.preinit ${VM_ARGS} ${JAVARTS20_ARGS} ${COMMON_ARGS} ${GETTING_STARTED_JAR} GCDeterministic ${RT_BENCH_ARGS} ${RT_STRESS_ARGS} ${JLT_STRESS_ARGS} ${VERBOSE}"
EXEC_TIME=`date '+%m%d%y-%H''%M'`
file_name=${HOST_NAME}-${RUN_NAME}-${EXEC_TIME}
touch ${file_name}
echo ${command_line} >> ${file_name}
echo ${command_line}
${command_line} >> ${file_name}
psrset -d 1
psradm -n 0
echo "# --- GCDeterministic run2 completed \n\n\n"

echo "# ------------------ GCDeterministic Run3 --------------------\n"
RUN_NAME='JavaRTS20-GCDeterministic-run3-ITC-BRT-MaxPrMaxAllocNoPauseResBytes10m-SRT-PrMinNormAllocNoPause-NoSJLT-PS1-Medium'
echo "launching run ${RUN_NAME}"
JAVARTS20_ARGS='-Xms64m -Xmx64m -XX:RTGCCriticalReservedBytes=10m -XX:+ITCRT -XX:+PrintGC'
psradm -i 0
psrset -c 0
RT_BENCH_ARGS='1000 10 10 500 0 max'
RT_STRESS_ARGS='1000 10 10 300 0 min'
JLT_STRESS_ARGS='0 10 10 10 0 norm'
command_line="/usr/sbin/psrset -e 1 ${JAVARTS20_VM_BIN} -Drtsj.precompile=nhrt.precompile -Drtsj.preload=itc.preload -Drtsj.preinit=itc.preinit ${VM_ARGS} ${JAVARTS20_ARGS} ${COMMON_ARGS} ${GETTING_STARTED_JAR} GCDeterministic ${RT_BENCH_ARGS} ${RT_STRESS_ARGS} ${JLT_STRESS_ARGS} ${VERBOSE}"
EXEC_TIME=`date '+%m%d%y-%H''%M'`
file_name=${HOST_NAME}-${RUN_NAME}-${EXEC_TIME}
touch ${file_name}
echo ${command_line} >> ${file_name}
echo ${command_line}
${command_line} >> ${file_name}
psrset -d 1
psradm -n 0
echo "# --- GCDeterministic run3 completed \n\n\n"

echo "# ------------------ GCDeterministic Run4 --------------------\n"
RUN_NAME='JavaRTS20-GCDeterministic-run4-ITC-BRT-MaxPrMaxAllocSmallPauseResBytes10m-SRT-PrMinNormAllocNoPause-NoSJLT-PS1-Medium'
echo "launching run ${RUN_NAME}"
JAVARTS20_ARGS='-Xms64m -Xmx64m -XX:+ITCRT -XX:RTGCCriticalReservedBytes=10m -XX:+PrintGC'
psradm -i 0
psrset -c 0
RT_BENCH_ARGS='1000 10 10 500 4 max'
RT_STRESS_ARGS='1000 10 10 300 0 min'
JLT_STRESS_ARGS='0 10 10 10 0 norm'
command_line="/usr/sbin/psrset -e 1 ${JAVARTS20_VM_BIN} -Drtsj.precompile=nhrt.precompile -Drtsj.preload=itc.preload -Drtsj.preinit=itc.preinit ${VM_ARGS} ${JAVARTS20_ARGS} ${COMMON_ARGS} ${GETTING_STARTED_JAR} GCDeterministic ${RT_BENCH_ARGS} ${RT_STRESS_ARGS} ${JLT_STRESS_ARGS} ${VERBOSE}"
EXEC_TIME=`date '+%m%d%y-%H''%M'`
file_name=${HOST_NAME}-${RUN_NAME}-${EXEC_TIME}
touch ${file_name}
echo ${command_line} >> ${file_name}
echo ${command_line}
${command_line} >> ${file_name}
psrset -d 1
psradm -n 0
echo "# --- GCDeterministic run4 completed \n\n\n"

echo "# ------------------ GCDeterministic Run5 --------------------\n"
RUN_NAME='JavaRTS20-GCDeterministic-run5-ITC-BRT-MaxPrNormAllocNoPause-SRT-PrMinNormAllocNoPause-NoSJLT-PS2-Medium'
echo "launching run ${RUN_NAME}"
JAVARTS20_ARGS='-Xms64m -Xmx64m -XX:+ITCRT -XX:RTGCCriticalReservedBytes=10m -XX:+PrintGC'
psradm -i 0
psradm -i 1
psrset -c 0 1
RT_BENCH_ARGS='1000 10 10 200 0 max'
RT_STRESS_ARGS='1000 10 10 200 0 min'
JLT_STRESS_ARGS='0 10 10 1000 0 norm'
command_line="/usr/sbin/psrset -e 1 ${JAVARTS20_VM_BIN} -Drtsj.precompile=nhrt.precompile -Drtsj.preload=itc.preload -Drtsj.preinit=itc.preinit ${VM_ARGS} ${JAVARTS20_ARGS} ${COMMON_ARGS} ${GETTING_STARTED_JAR} GCDeterministic ${RT_BENCH_ARGS} ${RT_STRESS_ARGS} ${JLT_STRESS_ARGS} ${VERBOSE}"
EXEC_TIME=`date '+%m%d%y-%H''%M'`
file_name=${HOST_NAME}-${RUN_NAME}-${EXEC_TIME}
touch ${file_name}
echo ${command_line} >> ${file_name}
echo ${command_line}
${command_line} >> ${file_name}
psrset -d 1
psradm -n 0
psradm -n 1
echo "# --- GCDeterministic run5 completed \n\n\n"

echo "# ------------------ GCDeterministic Run6 --------------------\n"
RUN_NAME='JavaRTS20-GCDeterministic-run6-ITC-BRT-MaxPrNormAllocNoPause-SRT-PrMinNormAllocNoPause-NoSJLT-PS2-Medium'
echo "launching run ${RUN_NAME}"
JAVARTS20_ARGS='-Xms64m -Xmx64m -XX:+ITCRT -XX:RTGCCriticalReservedBytes=10m -XX:+PrintGC'
psradm -i 0
psradm -i 1
psrset -c 0 1
RT_BENCH_ARGS='1000 10 10 25 0 max'
RT_STRESS_ARGS='1000 10 10 200 0 min'
JLT_STRESS_ARGS='0 10 10 1000 0 norm'
command_line="/usr/sbin/psrset -e 1 ${JAVARTS20_VM_BIN} -Drtsj.precompile=nhrt.precompile -Drtsj.preload=itc.preload -Drtsj.preinit=itc.preinit ${VM_ARGS} ${JAVARTS20_ARGS} ${COMMON_ARGS} ${GETTING_STARTED_JAR} GCDeterministic ${RT_BENCH_ARGS} ${RT_STRESS_ARGS} ${JLT_STRESS_ARGS} ${VERBOSE}"
EXEC_TIME=`date '+%m%d%y-%H''%M'`
file_name=${HOST_NAME}-${RUN_NAME}-${EXEC_TIME}
touch ${file_name}
echo ${command_line} >> ${file_name}
echo ${command_line}
${command_line} >> ${file_name}
psrset -d 1
psradm -n 0
psradm -n 1
echo "# --- GCDeterministic run6 completed \n\n\n"

echo "# ------------------ GCDeterministic Run7 --------------------\n"
RUN_NAME='JavaRTS20-GCDeterministic-run7-ITC-BRT-NormPrNoAllocNoPause-SRT-MinPrNormAllocNoPause-NoSJLT-PS1-Medium'
echo "launching run ${RUN_NAME}"
JAVARTS20_ARGS='-Xms64m -Xmx64m -XX:+ITCRT -XX:+PrintGC'
psradm -i 0
psrset -c 0
RT_BENCH_ARGS='1000 10 10 0 0 norm'
RT_STRESS_ARGS='1000 10 10 300 0 min'
JLT_STRESS_ARGS='0 10 10 800 0 norm'
command_line="/usr/sbin/psrset -e 1 ${JAVARTS20_VM_BIN} -Drtsj.precompile=nhrt.precompile -Drtsj.preload=itc.preload -Drtsj.preinit=itc.preinit ${VM_ARGS} ${JAVARTS20_ARGS} ${COMMON_ARGS} ${GETTING_STARTED_JAR} GCDeterministic ${RT_BENCH_ARGS} ${RT_STRESS_ARGS} ${JLT_STRESS_ARGS} ${VERBOSE}"
EXEC_TIME=`date '+%m%d%y-%H''%M'`
file_name=${HOST_NAME}-${RUN_NAME}-${EXEC_TIME}
touch ${file_name}
echo ${command_line} >> ${file_name}
echo ${command_line}
${command_line} >> ${file_name}
psrset -d 1
psradm -n 0
echo "# --- GCDeterministic run7 completed \n\n\n"

echo "# ------------------ GCDeterministic Run8 --------------------\n"
RUN_NAME='JavaRTS20-GCDeterministic-run8-ITC-BRT-NormPrMaxAllocNoPause-SRT-MinPrNormAllocNoPause-NoSJLT-PS1-Medium'
echo "launching run ${RUN_NAME}"
JAVARTS20_ARGS='-Xms64m -Xmx64m -XX:+ITCRT -XX:+PrintGC'
psradm -i 0
psrset -c 0
RT_BENCH_ARGS='1000 10 10 500 0 norm'
RT_STRESS_ARGS='1000 10 10 300 0 min'
JLT_STRESS_ARGS='0 10 10 800 0 norm'
command_line="/usr/sbin/psrset -e 1 ${JAVARTS20_VM_BIN} -Drtsj.precompile=nhrt.precompile -Drtsj.preload=itc.preload -Drtsj.preinit=itc.preinit ${VM_ARGS} ${JAVARTS20_ARGS} ${COMMON_ARGS} ${GETTING_STARTED_JAR} GCDeterministic ${RT_BENCH_ARGS} ${RT_STRESS_ARGS} ${JLT_STRESS_ARGS} ${VERBOSE}"
EXEC_TIME=`date '+%m%d%y-%H''%M'`
file_name=${HOST_NAME}-${RUN_NAME}-${EXEC_TIME}
touch ${file_name}
echo ${command_line} >> ${file_name}
echo ${command_line}
${command_line} >> ${file_name}
psrset -d 1
psradm -n 0
echo "# --- GCDeterministic run8 completed \n\n\n"

echo "# ------------------ GCDeterministic Run9 --------------------\n"
RUN_NAME='JavaRTS20-GCDeterministic-run9-ITC-BRT-NormPrMaxAllocNoPauseResBytes10m-SRT-MinPrNormAllocNoPause-NoSJLT-PS1-Medium'
echo "launching run ${RUN_NAME}"
JAVARTS20_ARGS='-Xms64m -Xmx64m -XX:+ITCRT  -XX:RTGCCriticalReservedBytes=10m -XX:+PrintGC'
psradm -i 0
psrset -c 0
RT_BENCH_ARGS='1000 10 10 500 0 norm'
RT_STRESS_ARGS='1000 10 10 300 0 min'
JLT_STRESS_ARGS='0 10 10 800 0 norm'
command_line="/usr/sbin/psrset -e 1 ${JAVARTS20_VM_BIN} -Drtsj.precompile=nhrt.precompile -Drtsj.preload=itc.preload -Drtsj.preinit=itc.preinit ${VM_ARGS} ${JAVARTS20_ARGS} ${COMMON_ARGS} ${GETTING_STARTED_JAR} GCDeterministic ${RT_BENCH_ARGS} ${RT_STRESS_ARGS} ${JLT_STRESS_ARGS} ${VERBOSE}"
EXEC_TIME=`date '+%m%d%y-%H''%M'`
file_name=${HOST_NAME}-${RUN_NAME}-${EXEC_TIME}
touch ${file_name}
echo ${command_line} >> ${file_name}
echo ${command_line}
${command_line} >> ${file_name}
psrset -d 1
psradm -n 0
echo "# --- GCDeterministic run9 completed \n\n\n"

echo "# ------------------ GCDeterministic Run10 --------------------\n"
RUN_NAME='JavaRTS20-GCDeterministic-run10-ITC-BRT-NormPrMaxAllocSmallPause-SRT-MinPrNormAllocNoPause-NoSJLT-PS1-Medium'
echo "launching run ${RUN_NAME}"
JAVARTS20_ARGS='-Xms64m -Xmx64m -XX:+ITCRT -XX:+PrintGC'
psradm -i 0
psrset -c 0
RT_BENCH_ARGS='1000 10 10 1000 4 norm'
RT_STRESS_ARGS='1000 10 10 300 0 min'
JLT_STRESS_ARGS='0 10 10 800 0 norm'
command_line="/usr/sbin/psrset -e 1 ${JAVARTS20_VM_BIN} -Drtsj.precompile=nhrt.precompile -Drtsj.preload=itc.preload -Drtsj.preinit=itc.preinit ${VM_ARGS} ${JAVARTS20_ARGS} ${COMMON_ARGS} ${GETTING_STARTED_JAR} GCDeterministic ${RT_BENCH_ARGS} ${RT_STRESS_ARGS} ${JLT_STRESS_ARGS} ${VERBOSE}"
EXEC_TIME=`date '+%m%d%y-%H''%M'`
file_name=${HOST_NAME}-${RUN_NAME}-${EXEC_TIME}
touch ${file_name}
echo ${command_line} >> ${file_name}
echo ${command_line}
${command_line} >> ${file_name}
psrset -d 1
psradm -n 0
echo "# --- GCDeterministic run10 completed \n\n\n"

echo "# ------------------ GCDeterministic Run11 --------------------\n"
RUN_NAME='JavaRTS20-GCDeterministic-run11-ITC-BRT-NormPrMaxAllocSmallPause-SRT-MinPrNormAllocSmallPause-NoSJLT-PS1-Medium'
echo "launching run ${RUN_NAME}"
JAVARTS20_ARGS='-Xms64m -Xmx64m -XX:+ITCRT -XX:+PrintGC'
psradm -i 0
psrset -c 0
RT_BENCH_ARGS='5000 10 10 200 4 norm'
RT_STRESS_ARGS='5000 10 10 50 4 min'
JLT_STRESS_ARGS='0 10 10 800 0 norm'
command_line="/usr/sbin/psrset -e 1 ${JAVARTS20_VM_BIN} -Drtsj.precompile=nhrt.precompile -Drtsj.preload=itc.preload -Drtsj.preinit=itc.preinit ${VM_ARGS} ${JAVARTS20_ARGS} ${COMMON_ARGS} ${GETTING_STARTED_JAR} GCDeterministic ${RT_BENCH_ARGS} ${RT_STRESS_ARGS} ${JLT_STRESS_ARGS} ${VERBOSE}"
EXEC_TIME=`date '+%m%d%y-%H''%M'`
file_name=${HOST_NAME}-${RUN_NAME}-${EXEC_TIME}
touch ${file_name}
echo ${command_line} >> ${file_name}
echo ${command_line}
${command_line} >> ${file_name}
psrset -d 1
psradm -n 0
echo "# --- GCDeterministic run11 completed \n\n\n"

echo "# ------------------ GCDeterministic Run12 --------------------\n"
RUN_NAME='JavaRTS20-GCDeterministic-run12-ITC-NormalMinFreeBytes10m-BRT-NormPrMaxAllocSmallPause-SRT-MinPrNormAllocSmallPause-NoSJLT-PS1-Medium'
echo "launching run ${RUN_NAME}"
JAVARTS20_ARGS='-Xms64m -Xmx64m -XX:+ITCRT -XX:NormalMinFreeBytes=10m -XX:+PrintGC'
psradm -i 0
psrset -c 0
RT_BENCH_ARGS='1000 10 10 500 4 norm'
RT_STRESS_ARGS='1000 10 10 300 4 min'
JLT_STRESS_ARGS='0 10 10 800 0 norm'
command_line="/usr/sbin/psrset -e 1 ${JAVARTS20_VM_BIN} -Drtsj.precompile=nhrt.precompile -Drtsj.preload=itc.preload -Drtsj.preinit=itc.preinit ${VM_ARGS} ${JAVARTS20_ARGS} ${COMMON_ARGS} ${GETTING_STARTED_JAR} GCDeterministic ${RT_BENCH_ARGS} ${RT_STRESS_ARGS} ${JLT_STRESS_ARGS} ${VERBOSE}"
EXEC_TIME=`date '+%m%d%y-%H''%M'`
file_name=${HOST_NAME}-${RUN_NAME}-${EXEC_TIME}
touch ${file_name}
echo ${command_line} >> ${file_name}
echo ${command_line}
${command_line} >> ${file_name}
psrset -d 1
psradm -n 0
echo "# --- GCDeterministic run12 completed \n\n\n"

# ------------------------------------------------------------
