
/*
 *
 *    Copyright  2007 Sun Microsystems, Inc. All rights reserved
 *
 *    Use is subject to license terms.
 *
 */

import javax.realtime.Clock;
import javax.realtime.AbsoluteTime;
import javax.realtime.RelativeTime;
import javax.realtime.SchedulingParameters;
import javax.realtime.PriorityParameters;
import javax.realtime.PriorityScheduler;
import javax.realtime.RealtimeThread;
import javax.realtime.Scheduler;

public class Deterministic implements Runnable {
    
    static {
        System.out.println("\n--------------- Running Deterministic Program ---------------");
        System.out.println("   Note:\n     All time measurements are expressed in microsecond units.");

        // Forces a load and initialization of Fibonacci classes
        Fibonacci1 f1 = new Fibonacci1(10);
        Fibonacci2 f2 = new Fibonacci2(10);
        f1.computeFib();
        f2.computeFib();
        
        // Forces a load and initialization of GarbageProducer classes
        GarbageProducer1 gp1 = new GarbageProducer1(10);
        GarbageProducer2 gp2 = new GarbageProducer2(10);
        gp1.produceGarbage(10);
        gp2.produceGarbage(10);

        // Forces a load and initialization of plugged in code
        // Uncomment the next 3 lines, and replace Fibonacci1 by the name
        // of your own StressingObject class
        // to preload and preinitialize your own stressing code.

        // Deterministic tmpDeterministic = new Deterministic(1);
        // tmpDeterministic.setVerbosity(false);
        // tmpDeterministic.stress("Fibonacci1", 10, 10);

        System.out.println("   Static initialization finished:");
        System.out.println("     ===> Fibonacci classes initialized and loaded");
    }
    
    // Stressing Iteration data ( captured as program parameters)
    int nb_outer_iterations = 0;
    int nb_inner_iterations = 0;
    int nb_stress_class_iterations = 0;
    int pause_time = 0;

    // Verbosity flag (captured as program parameter)
    boolean verbosity = false;

    // stress java.lang.Thread priority
    int thread_priority;

    // timestamps array for bench thread
    long[] wallclock_times_begin_loops = null; 
    long[] wallclock_times_end_loops = null; 

    // measurements instance
    Measurements measurements = null;
   
    // delegates result printing to measurement
    private void outputResults() {
        measurements.computeAndPrintStatResults(wallclock_times_begin_loops, wallclock_times_end_loops);
    }

    /** Instantiate a StressingObject from stressingObjectClassName and
        and stresses nb_inner_iterations times with this stressingObject
        which is supposed to iterate nb_stress_class_iterations times by itself */
    void stress(String stressingObjectClassName, int nb_inner_iterations, int nb_stress_class_iterations) {
        StressingObject so = null;
        
        try {
            so = (StressingObject) (Class.forName(stressingObjectClassName).newInstance());
            so.setStressClassIterations(nb_stress_class_iterations);
            for (int i = 1; i <= nb_inner_iterations; i++) {
                so.stress();
            }
        }
        catch(Exception e) {System.out.println(e);}
    }


    // Fibonacci computation stress method
    // computes 2 fibonacci sequences "nb_outer_fib_iterations" times
    //  -  fib_number_to_calculate : quantity of fib numbers to compute
    void computeFibs(int nb_inner_iterations, int nb_stress_class_iterations) {
        Fibonacci1 f1 = new Fibonacci1(nb_stress_class_iterations);
        Fibonacci2 f2 = new Fibonacci2(nb_stress_class_iterations);
        
        for (int i = 1; i <= nb_inner_iterations; i++) {
            f1.computeFib();
            f2.computeFib();
        }
    }

    /** Creates a new instance of Deterministic */
    Deterministic(int nb_loops) {

        wallclock_times_begin_loops = new long[nb_loops];
        wallclock_times_end_loops = new long[nb_loops];
        
        measurements = new Measurements(nb_loops);
    }
    
    /** Changes verbosity level */
    private void setVerbosity(boolean verbose_flag) {
        verbosity = verbose_flag;
        measurements.setVerbosity(verbosity);
    }


    // For additional time consumption from a time-sharing thread
    public void run() {
        try {
            for (int i = 0; i < nb_outer_iterations; i++) {
                // fibonacci calculation
                computeFibs(this.nb_inner_iterations, this.nb_stress_class_iterations);

                // Stressing with your own code.
                // Replace Fibonacci1 by your StressingObject class name
                // and uncomment the following line to stress with your own code.
                // stress("Fibonacci1", nb_inner_iterations, nb_stress_class_iterations);
                
                // parameterized pause time
                if (this.pause_time != 0) Thread.currentThread().sleep((long) this.pause_time);
            }
        }
        catch (InterruptedException ie) {
            System.out.println("java.lang stress thread interrupted");
        }
    }

    class RealTimeFibonacciLoops extends RealtimeThread {
        boolean records_time_measures;
        int nb_outer_iterations = 0;
        int nb_inner_iterations = 0;
        int nb_stress_class_iterations = 0;
        int pause_time = 0;


        RealTimeFibonacciLoops(boolean time_recording_state,
                               int outer_iterations,
                               int inner_iterations,
                               int stress_class_iterations,
                               int time_to_pause,
                               SchedulingParameters scheduling) {
            super(scheduling);
            records_time_measures = time_recording_state;
            nb_outer_iterations = outer_iterations;
            nb_inner_iterations = inner_iterations;
            nb_stress_class_iterations = stress_class_iterations;
            pause_time = time_to_pause;
        }


        public void run() {
                
            final Clock rtClock = Clock.getRealtimeClock();
            final RelativeTime time_to_sleep = new RelativeTime(pause_time, 0);

            // the AbsoluteTime from which to measure
            AbsoluteTime rtWallClockTimeBefore = rtClock.getTime();
            AbsoluteTime rtWallClockTimeAfter = rtClock.getTime();

            int no_loop = 0;
            try {
                while (no_loop < nb_outer_iterations) {
                    if (records_time_measures) {
                        // recording time before computation and allocation 
                        rtClock.getTime(rtWallClockTimeBefore);
                        wallclock_times_begin_loops[no_loop] =
                            (rtWallClockTimeBefore.getMilliseconds() * 1000000L) +
                            rtWallClockTimeBefore.getNanoseconds();
                    }
            
                    // Fibonacci computation sample
                    Deterministic.this.computeFibs(nb_inner_iterations, nb_stress_class_iterations);

                    // stressing with your own code.
                    // Replace Fibonacci1 by your StressingObject class name
                    // and uncomment the following line to stress with your own code.
                    // Deterministic.this.stress("Fibonacci1", nb_inner_iterations, nb_stress_class_iterations);
                
                    // parameterized pause if asked for
                    if (pause_time != 0) sleep(time_to_sleep);

                    if (records_time_measures) {
                        // recording time after computation and allocation 
                        rtClock.getTime(rtWallClockTimeAfter);
                        wallclock_times_end_loops[no_loop] =
                            (rtWallClockTimeAfter.getMilliseconds() * 1000000L) +
                            rtWallClockTimeAfter.getNanoseconds();
                    }

                    no_loop++;
                }
            }
            catch (InterruptedException ie) {
                System.out.println("javax.RealtimeThread interrupted");
            }
        }
    }




    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        
        // local rt thread variables
        Thread jlt_stress_thread = null;
        RealTimeFibonacciLoops rt_bench_thread = null;
        RealTimeFibonacciLoops rt_stress_thread = null;

        int jlt_stress_thread_priority = 0;
        int rt_bench_thread_priority = 0;
        int rt_stress_thread_priority = 0;

        // local run variables
        boolean jlt_stress_thread_present = false;
        boolean jrt_stress_thread_present = false;

        // extract program command-line parameters 
           // The bench RT thread parameters (all mandatory)
           int bench_nb_outer_iterations = new Integer(args[0]).intValue();
           int bench_nb_inner_iterations = new Integer(args[1]).intValue();
           int bench_nb_stress_class_iterations = new Integer(args[2]).intValue();
           int bench_pause_time  = new Integer(args[3]).intValue();
           String bench_priority_level = args[4];

           // The javax.RealtimeThread stress thread parameters (all mandatory)
           int jrt_stress_nb_outer_iterations = new Integer(args[5]).intValue();
           int jrt_stress_nb_inner_iterations = new Integer(args[6]).intValue();
           int jrt_stress_nb_stress_class_iterations = new Integer(args[7]).intValue();
           int jrt_stress_pause_time  = new Integer(args[8]).intValue();
           String jrt_stress_priority_level = args[9];

           // The java.lang.Thread stress thread parameters (all mandatory)
           int jlt_stress_nb_outer_iterations = new Integer(args[10]).intValue();
           int jlt_stress_nb_inner_iterations = new Integer(args[11]).intValue();
           int jlt_stress_nb_stress_class_iterations = new Integer(args[12]).intValue();
           int jlt_stress_pause_time  = new Integer(args[13]).intValue();
           String jlt_stress_priority_level = args[14];

        // Initialization   
        PriorityScheduler ps = (PriorityScheduler)(Scheduler.getDefaultScheduler());
        final Deterministic d = new Deterministic(bench_nb_outer_iterations);

        // verbosity level (optional)
        if ((args.length >= 16) && (args[15].equals("verbose"))) d.setVerbosity(true);

        // Bench realtime thread instanciation
        if ((bench_nb_outer_iterations == 0) || 
            (bench_nb_inner_iterations == 0) ||
            (bench_nb_stress_class_iterations == 0)) {
            System.out.println("invalid number of iterations specified for bench thread");
            System.exit(1);
        }
        else {
            if (bench_priority_level.equalsIgnoreCase("max"))
               rt_bench_thread_priority = ps.getMaxPriority();
            else if (bench_priority_level.equalsIgnoreCase("norm"))
               rt_bench_thread_priority = ps.getNormPriority();
            else rt_bench_thread_priority = ps.getMinPriority();
            
            rt_bench_thread =
                d.new RealTimeFibonacciLoops(
                   true,
                   bench_nb_outer_iterations,
                   bench_nb_inner_iterations,
                   bench_nb_stress_class_iterations,
                   bench_pause_time, 
                   new PriorityParameters(rt_bench_thread_priority));
        }

        // Realtime stress thread instanciation
        if ((jrt_stress_nb_outer_iterations != 0) && 
            (jrt_stress_nb_inner_iterations != 0) &&
            (jrt_stress_nb_stress_class_iterations != 0)) {

            jrt_stress_thread_present = true;

            if (jrt_stress_priority_level.equalsIgnoreCase("max"))
               rt_stress_thread_priority = ps.getMaxPriority();
            else if (jrt_stress_priority_level.equalsIgnoreCase("norm"))
               rt_stress_thread_priority = ps.getNormPriority();
            else rt_stress_thread_priority = ps.getMinPriority();

            rt_stress_thread =
                d.new RealTimeFibonacciLoops(
                   false,
                   jrt_stress_nb_outer_iterations,
                   jrt_stress_nb_inner_iterations,
                   jrt_stress_nb_stress_class_iterations,
                   jrt_stress_pause_time, 
                   new PriorityParameters(rt_stress_thread_priority));
        }
        else jrt_stress_thread_present = false;

        // java.lang.Thread stress thread value checking
        if ((jlt_stress_nb_outer_iterations != 0) &&
            (jlt_stress_nb_inner_iterations != 0) &&
            (jlt_stress_nb_stress_class_iterations != 0)) {

            jlt_stress_thread_present = true;

            if (jlt_stress_priority_level.equalsIgnoreCase("max"))
               jlt_stress_thread_priority = Thread.MAX_PRIORITY;
            else if (jlt_stress_priority_level.equalsIgnoreCase("norm"))
               jlt_stress_thread_priority = Thread.NORM_PRIORITY;
            else jlt_stress_thread_priority = Thread.MIN_PRIORITY;

            jlt_stress_thread = new Thread(d);
            jlt_stress_thread.setPriority(jlt_stress_thread_priority);
        }
        else {
            jlt_stress_thread_present = false;
        }

        // Iteration data ( captured as program parameters)
        d.nb_outer_iterations = jlt_stress_nb_outer_iterations;
        d.nb_inner_iterations = jlt_stress_nb_inner_iterations;
        d.nb_stress_class_iterations = jlt_stress_nb_stress_class_iterations;
        d.pause_time = jlt_stress_pause_time;
        d.thread_priority = jlt_stress_thread_priority;

        System.out.println("   Initialization and configuration of program finished ");

        // recap of options 
        System.out.println("\n============================================");
        System.out.println("    Deterministic program parameters");
        System.out.println("============================================");
        System.out.println("   The options used for this run are:   ");
        System.out.println("----------------------------------------");
        System.out.println("  Realtime bench thread parameters:");
        System.out.println("  =================================");
        System.out.println("   Number of outer loops: " + bench_nb_outer_iterations);
        System.out.println("   Number of inner iterations: " + bench_nb_inner_iterations);
        System.out.println("   Number of stress classes iterations: " + bench_nb_stress_class_iterations);
        System.out.println("   Inner pause time: " + bench_pause_time);
        System.out.println("   Priority level: " + bench_priority_level);
        System.out.println("   Effective priority assigned: " + rt_bench_thread_priority);
        System.out.println();

        if (jrt_stress_thread_present) {
            System.out.println("  Realtime stress thread parameters:");
            System.out.println("  =================================");
            System.out.println("   Number of outer loops: " + jrt_stress_nb_outer_iterations);
            System.out.println("   Number of inner iterations: " + jrt_stress_nb_inner_iterations);
            System.out.println("   Number of stress classes iterations: " + jrt_stress_nb_stress_class_iterations);
            System.out.println("   Inner pause time: " + jrt_stress_pause_time);
            System.out.println("   Priority level: " + jrt_stress_priority_level);
            System.out.println("   Effective priority assigned: " + rt_stress_thread_priority);
            System.out.println();
        }

        if (jlt_stress_thread_present) {
            System.out.println("  java.lang.Thread stress thread parameters:");
            System.out.println("  ==========================================");
            System.out.println("   Number of outer loops: " + d.nb_outer_iterations);
            System.out.println("   Number of inner iterations: " + d.nb_inner_iterations);
            System.out.println("   Number of stress classes iterations: " + d.nb_stress_class_iterations);
            System.out.println("   Inner pause time: " + d.pause_time);
            System.out.println("   Priority level: " + jlt_stress_priority_level);
            System.out.println("   Effective priority assigned: " + d.thread_priority);
            System.out.println();
        }
        
        System.out.println("  Output detail level: " + (d.verbosity?"detailed":"summary"));
        System.out.println("----------------------------------------\n");


        System.out.println("\n ==================== Starting " + bench_nb_outer_iterations + " iterations ===================================== \n ");

        // stabilizes meory and output state before allocating objects
        System.gc();
        System.out.println("Total amount of VM memory : " + Runtime.getRuntime().totalMemory());
        System.gc();
        System.out.println("Amount of free  VM memory : " + Runtime.getRuntime().freeMemory());
        System.gc();
        System.out.println("Max amount of   VM memory : " + Runtime.getRuntime().maxMemory());
        
        // starts the java.lang.Thread stress thread
        if (jlt_stress_thread_present) {
            System.out.println("   Starting java.lang.Thread stress thread");
            jlt_stress_thread.start();
        }

        // starts the javx.RealtimeTHread bench thread
        System.out.println("   Starting javax.Realtime bench thread");
        rt_bench_thread.start();
        
        // starts the javax.RealtimeThread stress thread
        if (jrt_stress_thread_present) {
            System.out.println("   Starting javax.Realtime stress thread");
            rt_stress_thread.start();
        }

        try {
            rt_bench_thread.join(); 
            System.out.println("   Bench javax.Realtime thread terminated");

            if (jrt_stress_thread_present) {
                rt_stress_thread.join();
                System.out.println("   Stress javax.Realtime thread terminated");
            }
            
            if (jlt_stress_thread_present) {
                jlt_stress_thread.join();
                System.out.println("   Stress java.lang.Thread terminated");
            }                

            System.out.println("\n ==================== Requested " + bench_nb_outer_iterations + " iterations finished ===================================== \n");

            System.out.println("\n ==================== Starting output results ==================== \n");
            d.outputResults();
            System.out.println("\n  ==================== Finished results output ==================== \n ");

        }
        catch (InterruptedException ie) {
            System.out.println(ie);
        }
        
    }
    
}








